/* ============================================================================
 *                         t i m e r _ i n t e r f a c e . h
 * ============================================================================
 * Cytonome CAB 3.0 Cypress CY8C5868AXI-LP035 Firmware
 * Copyright Cytonome ST, LLC 2022
 * All Rights Reserved
 *
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Cytonome ST, LLC.
 *
 * For CAB 3.0 Rev B17
 *
 * Revision History:
 *  001 14 Jul 22 <sek> created
 *  002 21 Jul 22 <sek> systimers
 *  003 26 Jul 22 <sek> #ifndef fencing
 *  004 26 Jul 22 <sek> HOUR_OF_OPERATION timers
 *  005 02 Aug 22 <sek> systimer_pause(), systimer_resume()
 *  006 02 Aug 22 <sek> moved systimer timeout values here from main.c
 *  007 03 Aug 22 <sek> I2C_TIMEOUT, FAN_MEASUREMENT_TIMEOUT, systimer_stop()
 *  008 05 Aug 22 <sek> SYSTIMER_EEPROM_DISPLAY, EEPROM_DISPLAY_TIME
 *  009 08 Aug 22 <sek> SYSTIMER_B410V_DELAY
 *  00A 10 Aug 22 <sek> SYSTIMER_FPGA_BUS_UPDATE
 *  00B 26 Aug 22 <sek> #define B410_VOLTAGE_CHANGE_DELAY   2005, B410_VOLTAGE_CHANGE_TO_ZERO_DELAY  10005
 *  00C 29 Aug 22 <sek> #define FANS_MONITOR_TIME                   1011
 *  00D 01 Sep 22 <sek> Interlock monitor SYSTIMER_INTERLOCK_MONITOR, INTERLOCK_MONITOR_TIME
 *  00E 06 Sep 22 <sek> B410V_RAMP_UPDATE_TIME, B3KV_RAMP_UPDATE_TIME, B3KV_VOLTAGE_CHANGE_DELAY, B3KV_VOLTAGE_CHANGE_TO_ZERO_DELAY
 *  00F 03 Oct 22 <sek> changed FAN_MEASUREMENT_TIMEOUT to 25mS, to measure observed 150Hz Fan Tach signal
 *  010 22 Oct 22 <sek> changed B410V_VOLTAGE_CHANGE_DELAY from 2013 to 3013
 *  011 03 Nov 22 <sek> SYSTIMER_SHT31A_MEASUREMENT, SHT31A_TIMEOUT
 *  012 14 Nov 22 <sek> #define FANS_MONITOR_TIME   3011
 *  013 20 Jan 23 <sek> INPUT_LINES_MONITOR_TIME    10  (was 5)
 *  014 25 Jan 23 <sek> INPUT_LINES_MONITOR_TIME    5  (problem was elesewhere!), DISPLAY_UPDATE_TIME 1007 (was 1000)
 *  015 25 Jan 23 <sek> #define INPUT_LINES_TRIGGER_TIME 207
* ============================================================================
*/
#ifndef TIMER_INTERFACE_H
#define TIMER_INTERFACE_H

int16 GetmSCount(void);

volatile uint32 GetSysTicksInSeconds(void);
void SysTickTimersInitialize(void);

// enumeration of all timers used in the system, used as indices into an array of timer structures
enum 
{
    SYSTIMER_HV_MONITOR,
    SYSTIMER_VHV_MONITOR,
    SYSTIMER_LED_UPDATE,
    SYSTIMER_INPUT_LINES_MONITOR,
    SYSTIMER_TEMPERATURE_MONITOR,
    SYSTIMER_FANS_MONITOR,
    SYSTIMER_INTERLOCK_MONITOR,
    SYSTIMER_DISPLAY_UPDATE,
    SYSTIMER_DISPLAY_DELAY,
    SYSTIMER_HOUR_OF_OPERATION,
    SYSTIMER_HOUR_OF_VHV_OPERATION,
    SYSTIMER_EEPROM_DISPLAY,
    SYSTIMER_EEPROM_UPDATE,
    
    SYSTIMER_B410V_UPDATE,              // for testing only
    SYSTIMER_B410V_RAMP_UPDATE,         // for testing only
    SYSTIMER_B410V_DELAY,
    SYSTIMER_B3KV_FPGA_BUS_UPDATE,
    SYSTIMER_B3KV_RAMP_UPDATE,          // for testing only
    SYSTIMER_B3KV_DELAY,
    
    SYSTIMER_I2C_TIMEOUT,
    SYSTIMER_SPI_TIMEOUT,
    SYSTIMER_FAN_MEASUREMENT_TIMEOUT,
    SYSTIMER_SHT31A_MEASUREMENT,
    
    SYSTIMER_MAX
};

// systimer timeout values
// note the LSD variations, so none occur on the same 1mS tick
#define HV_MONITOR_SAMPLE_TIME              101
#define VHV_MONITOR_SAMPLE_TIME             103
#define LED_UPDATE_TIME                     1005
#define INPUT_LINES_TRIGGER_TIME            207 // 105
#define INPUT_LINES_MONITOR_TIME            5
#define TEMPERATURE_MONITOR_TIME            5009
#define FANS_MONITOR_TIME                   3011
#define INTERLOCK_MONITOR_TIME              111
#define DISPLAY_UPDATE_TIME                 1007
#define DISPLAY_DELAY_TIME                  103
#define HOUR_OF_OPERATION_TIME              60001
#define HOUR_OF_VHV_OPERATION_TIME          60002
#define EEPROM_DISPLAY_TIME                 60003       // one minute
#define EEPROM_UPDATE_TIME                  60000       // one minute, counted to 10
#define B410V_UPDATE_TIME                   109         // time to check B410V state, for testing purposes only
#define B410V_RAMP_UPDATE_TIME              10015       // time to step ramp, for testing purposes only
#define B410V_VOLTAGE_CHANGE_DELAY          2013        // ==> to be determined
#define B410V_VOLTAGE_CHANGE_TO_ZERO_DELAY  10013       // based on testing
#define B3KV_FPGA_BUS_UPDATE_TIME           107         // time to check FPGA bus for new value
#define B3KV_RAMP_UPDATE_TIME               10009       // time to step ramp, for testing purposes only
#define B3KV_VOLTAGE_CHANGE_DELAY           2009        // ==> to be determined, was 2009
#define B3KV_VOLTAGE_CHANGE_TO_ZERO_DELAY   10009       // ==> to be determined

#define I2C_TIMEOUT                         10
#define FAN_MEASUREMENT_TIMEOUT             50
#define SHT31A_TIMEOUT                      100         // delay from requesting measurement to reading it

#define MINUTES_PER_HOUR                    60          // for tracking operation time
#define MINUTES_PER_EEPROM_UPDATE           10          

/*
    returns true if a timer is expired.
*/
BOOL systimer_expired(uint8 timerIndex);

/*
    resets a timer for a new expiration time.
*/
void systimer_start(uint8 timerIndex, uint16 duration);
void systimer_pause(uint8 timerIndex);
void systimer_resume(uint8 timerIndex);
void systimer_stop(uint8 timerIndex);



#endif      // TIMER_INTERFACE_H

/* [] END OF FILE */
